{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#bwa-mem-PE.cwl",
            "label": "bwa-mem-PE-0.7.15--1",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/bwa:0.7.15--1"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4
                }
            ],
            "baseCommand": [
                "bwa",
                "mem"
            ],
            "inputs": [
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.15--1/nthreads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "prefix": "-t",
                        "position": 1
                    },
                    "doc": "number of cpu cores to be used"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.15--1/fadir",
                    "type": "Directory",
                    "doc": "directory containing FastA file and index"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.15--1/ref",
                    "type": "string",
                    "doc": "name of reference (e.g., hs37d5)"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.15--1/fq1",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "FastQ file from next-generation sequencers"
                },
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.15--1/fq2",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 7
                    },
                    "doc": "FastQ file from next-generation sequencers"
                }
            ],
            "stdout": "output.sam",
            "arguments": [
                {
                    "position": 2,
                    "prefix": "-K",
                    "valueFrom": "100000000"
                },
                {
                    "position": 3,
                    "valueFrom": "-Y"
                },
                {
                    "position": 4,
                    "valueFrom": "-p"
                },
                {
                    "position": 5,
                    "valueFrom": "$(inputs.fadir.path)/$(inputs.ref).fa"
                }
            ],
            "outputs": [
                {
                    "id": "#bwa-mem-PE.cwl/bwa-mem-PE-0.7.15--1/sam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2573",
                    "outputBinding": {
                        "glob": "output.sam"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "download-sra: A simple download tool to get .sra file",
            "doc": "A simple download tool to get .sra file from a repository of INSDC members. https://github.com/inutano/download-sra",
            "hints": [
                {
                    "dockerPull": "quay.io/inutano/download-sra:0.1.2",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "ncbi",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "id": "#download-sra.cwl/repo"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#download-sra.cwl/run_ids"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*sra"
                    },
                    "id": "#download-sra.cwl/sraFiles"
                }
            ],
            "id": "#download-sra.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "fastqc",
            "inputs": [
                {
                    "id": "#fastqc.cwl/fastq",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "FastQ file from next-generation sequencers"
                },
                {
                    "id": "#fastqc.cwl/nthreads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "prefix": "--threads"
                    },
                    "doc": "number of cpu cores to be used"
                }
            ],
            "outputs": [
                {
                    "id": "#fastqc.cwl/qc",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_fastqc.html"
                    }
                }
            ],
            "label": "fastqc",
            "arguments": [
                {
                    "position": 1,
                    "prefix": "-o",
                    "valueFrom": "."
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/fastqc:0.11.7--pl5.22.0_2"
                }
            ],
            "id": "#fastqc.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "pfastq-dump: A bash implementation of parallel-fastq-dump, parallel fastq-dump wrapper",
            "doc": "pfastq-dump is a bash implementation of parallel-fastq-dump, parallel fastq-dump wrapper. --stdout option is additionally supported, but almost same features. It also uses -N and -X options of fastq-dump to specify blocks of data to be decompressed separately. https://github.com/inutano/pfastq-dump",
            "hints": [
                {
                    "dockerPull": "quay.io/inutano/sra-toolkit:v2.9.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "pfastq-dump"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--gzip"
                    },
                    "id": "#pfastq-dump.cwl/gzip"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#pfastq-dump.cwl/nthreads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--readids"
                    },
                    "id": "#pfastq-dump.cwl/readids"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--skip-technical"
                    },
                    "id": "#pfastq-dump.cwl/skip_technical"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--split-files"
                    },
                    "id": "#pfastq-dump.cwl/split_files"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--split-spot"
                    },
                    "id": "#pfastq-dump.cwl/split_spot"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#pfastq-dump.cwl/sraFiles"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*fastq*"
                    },
                    "id": "#pfastq-dump.cwl/fastqFiles"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*_1.fastq*"
                    },
                    "id": "#pfastq-dump.cwl/forward"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*_2.fastq*"
                    },
                    "id": "#pfastq-dump.cwl/reverse"
                }
            ],
            "id": "#pfastq-dump.cwl"
        },
        {
            "class": "CommandLineTool",
            "id": "#samtools-sam2bam.cwl",
            "label": "samtools-sam2bam-1.9--h8ee4bcc_1",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h8ee4bcc_1"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-bS"
            ],
            "inputs": [
                {
                    "id": "#samtools-sam2bam.cwl/samtools-sam2bam-1.9--h8ee4bcc_1/sam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2573",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "SAM alignment file"
                }
            ],
            "outputs": [
                {
                    "id": "#samtools-sam2bam.cwl/samtools-sam2bam-1.9--h8ee4bcc_1/bam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "outputBinding": {
                        "glob": "output.bam"
                    }
                }
            ],
            "stdout": "output.bam",
            "arguments": []
        },
        {
            "class": "CommandLineTool",
            "id": "#samtools-sort.cwl",
            "label": "samtools-sam2bam-1.9--h8ee4bcc_1",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h8ee4bcc_1"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "inputs": [
                {
                    "id": "#samtools-sort.cwl/samtools-sam2bam-1.9--h8ee4bcc_1/nthreads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "prefix": "-@",
                        "position": 1
                    },
                    "doc": "number of cpu cores to be used"
                },
                {
                    "id": "#samtools-sort.cwl/samtools-sam2bam-1.9--h8ee4bcc_1/bam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "BAM alignment file"
                }
            ],
            "outputs": [
                {
                    "id": "#samtools-sort.cwl/samtools-sam2bam-1.9--h8ee4bcc_1/sorted-bam",
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "outputBinding": {
                        "glob": "output.sort.bam"
                    }
                }
            ],
            "stdout": "output.sort.bam",
            "arguments": []
        },
        {
            "class": "CommandLineTool",
            "id": "#trimmomaticPE.cwl",
            "label": "trimmomatic-0.38",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/trimmomatic:0.38--1"
                }
            ],
            "baseCommand": [
                "java",
                "-jar"
            ],
            "inputs": [
                {
                    "id": "#trimmomaticPE.cwl/trimmomatic-0.38/nthreads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "prefix": "-threads",
                        "position": 3
                    },
                    "doc": "number of cpu cores to be used"
                },
                {
                    "id": "#trimmomaticPE.cwl/trimmomatic-0.38/fq1",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "FastQ file from next-generation sequencers"
                },
                {
                    "id": "#trimmomaticPE.cwl/trimmomatic-0.38/fq2",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "FastQ file from next-generation sequencers"
                }
            ],
            "outputs": [
                {
                    "id": "#trimmomaticPE.cwl/trimmomatic-0.38/trimFq1P",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.fq1.basename).trim.1P.fastq"
                    }
                },
                {
                    "id": "#trimmomaticPE.cwl/trimmomatic-0.38/trimFq1U",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.fq1.basename).trim.1U.fastq"
                    }
                },
                {
                    "id": "#trimmomaticPE.cwl/trimmomatic-0.38/trimFq2P",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.fq2.basename).trim.2P.fastq"
                    }
                },
                {
                    "id": "#trimmomaticPE.cwl/trimmomatic-0.38/trimFq2U",
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.fq2.basename).trim.2U.fastq"
                    }
                }
            ],
            "arguments": [
                {
                    "position": 1,
                    "valueFrom": "/usr/local/share/trimmomatic/trimmomatic.jar"
                },
                {
                    "position": 2,
                    "valueFrom": "PE"
                },
                {
                    "position": 6,
                    "valueFrom": "$(inputs.fq1.basename).trim.1P.fastq"
                },
                {
                    "position": 7,
                    "valueFrom": "$(inputs.fq1.basename).trim.1U.fastq"
                },
                {
                    "position": 8,
                    "valueFrom": "$(inputs.fq2.basename).trim.2P.fastq"
                },
                {
                    "position": 9,
                    "valueFrom": "$(inputs.fq2.basename).trim.2U.fastq"
                },
                {
                    "position": 10,
                    "valueFrom": "ILLUMINACLIP:/usr/local/share/trimmomatic/adapters/TruSeq2-PE.fa:2:40:15"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "test-workflow",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "(optional) The repository from which the data was downloaded (ncbi/ebi/ddbj). Default value is NCBI.",
                    "id": "#main/download_repo"
                },
                {
                    "type": "Directory",
                    "doc": "directory containing FastA file and index for BWA aligner",
                    "id": "#main/fadir"
                },
                {
                    "type": "int",
                    "doc": "The number of cores to be used for parallel exec of fastq-dump",
                    "id": "#main/nthreads"
                },
                {
                    "type": "string",
                    "doc": "name of reference (e.g., hs37d5) for BWA aligner",
                    "id": "#main/ref"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "A list of SRA Run ID such as ERR034597",
                    "id": "#main/sra_run_ids"
                }
            ],
            "steps": [
                {
                    "label": "download_sra",
                    "doc": "Download .sra format sequence data from NCBI Sequence Read Archive",
                    "run": "#download-sra.cwl",
                    "in": [
                        {
                            "source": "#main/download_repo",
                            "id": "#main/download_sra/repo"
                        },
                        {
                            "source": "#main/sra_run_ids",
                            "id": "#main/download_sra/run_ids"
                        }
                    ],
                    "out": [
                        "#main/download_sra/sraFiles"
                    ],
                    "id": "#main/download_sra"
                },
                {
                    "label": "map",
                    "doc": "Mapping onto a reference genome",
                    "run": "#bwa-mem-PE.cwl",
                    "in": [
                        {
                            "source": "#main/fadir",
                            "id": "#main/map/fadir"
                        },
                        {
                            "source": "#main/trimPE/trimFq1P",
                            "id": "#main/map/fq1"
                        },
                        {
                            "source": "#main/trimPE/trimFq2P",
                            "id": "#main/map/fq2"
                        },
                        {
                            "source": "#main/ref",
                            "id": "#main/map/ref"
                        }
                    ],
                    "out": [
                        "#main/map/sam"
                    ],
                    "id": "#main/map"
                },
                {
                    "label": "pfastq-dump",
                    "doc": "parallel execution of fastq-dump to convert .sra to .fastq.gz",
                    "run": "#pfastq-dump.cwl",
                    "in": [
                        {
                            "source": "#main/nthreads",
                            "id": "#main/pfastq_dump/nthreads"
                        },
                        {
                            "source": "#main/download_sra/sraFiles",
                            "id": "#main/pfastq_dump/sraFiles"
                        }
                    ],
                    "out": [
                        "#main/pfastq_dump/forward",
                        "#main/pfastq_dump/reverse"
                    ],
                    "id": "#main/pfastq_dump"
                },
                {
                    "label": "qc1",
                    "doc": "Quality control for fastq file (fq1) before trimming",
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/pfastq_dump/forward",
                            "id": "#main/qc1/fastq"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/qc1/nthreads"
                        }
                    ],
                    "out": [
                        "#main/qc1/qc"
                    ],
                    "id": "#main/qc1"
                },
                {
                    "label": "qc1P",
                    "doc": "Quality control for fastq file (fq1) after trimming",
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/trimPE/trimFq1P",
                            "id": "#main/qc1P/fastq"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/qc1P/nthreads"
                        }
                    ],
                    "out": [
                        "#main/qc1P/qc"
                    ],
                    "id": "#main/qc1P"
                },
                {
                    "label": "qc2",
                    "doc": "Quality control for fastq file (fq2) before trimming",
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/pfastq_dump/reverse",
                            "id": "#main/qc2/fastq"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/qc2/nthreads"
                        }
                    ],
                    "out": [
                        "#main/qc2/qc"
                    ],
                    "id": "#main/qc2"
                },
                {
                    "label": "qc2P",
                    "doc": "Quality control for fastq file (fq2) after trimming",
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/trimPE/trimFq2P",
                            "id": "#main/qc2P/fastq"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/qc2P/nthreads"
                        }
                    ],
                    "out": [
                        "#main/qc2P/qc"
                    ],
                    "id": "#main/qc2P"
                },
                {
                    "label": "sam2bam",
                    "doc": "Convert SAM to BAM",
                    "run": "#samtools-sam2bam.cwl",
                    "in": [
                        {
                            "source": "#main/map/sam",
                            "id": "#main/sam2bam/sam"
                        }
                    ],
                    "out": [
                        "#main/sam2bam/bam"
                    ],
                    "id": "#main/sam2bam"
                },
                {
                    "label": "sort",
                    "doc": "Sort BAM",
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#main/sam2bam/bam",
                            "id": "#main/sort/bam"
                        }
                    ],
                    "out": [
                        "#main/sort/sorted-bam"
                    ],
                    "id": "#main/sort"
                },
                {
                    "label": "trimPE",
                    "doc": "adaptor trimming",
                    "run": "#trimmomaticPE.cwl",
                    "in": [
                        {
                            "source": "#main/pfastq_dump/forward",
                            "id": "#main/trimPE/fq1"
                        },
                        {
                            "source": "#main/pfastq_dump/reverse",
                            "id": "#main/trimPE/fq2"
                        }
                    ],
                    "out": [
                        "#main/trimPE/trimFq1P",
                        "#main/trimPE/trimFq2P"
                    ],
                    "id": "#main/trimPE"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/sam2bam/bam",
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc1/qc",
                    "id": "#main/oqc1"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc1P/qc",
                    "id": "#main/oqc1P"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc2/qc",
                    "id": "#main/oqc2"
                },
                {
                    "type": "File",
                    "outputSource": "#main/qc2P/qc",
                    "id": "#main/oqc2P"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sort/sorted-bam",
                    "id": "#main/osort"
                },
                {
                    "type": "File",
                    "outputSource": "#main/map/sam",
                    "id": "#main/sam"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "edam": "http://edamontology.org/"
    }
}
